### Encoding: UTF-8

### Name: nleqslv
### Title: Solving systems of non linear equations with Broyden or Newton
### Aliases: nleqslv
### Keywords: nonlinear optimize

### ** Examples

# Dennis Schnabel example 6.5.1 page 149
dslnex <- function(x) {
    y <- numeric(2)
    y[1] <- x[1]^2 + x[2]^2 - 2
    y[2] <- exp(x[1]-1) + x[2]^3 - 2
    y
}

jacdsln <- function(x) {
    n <- length(x)
    Df <- matrix(numeric(n*n),n,n)
    Df[1,1] <- 2*x[1]
    Df[1,2] <- 2*x[2]
    Df[2,1] <- exp(x[1]-1)
    Df[2,2] <- 3*x[2]^2

    Df
}

BADjacdsln <- function(x) {
    n <- length(x)
    Df <- matrix(numeric(n*n),n,n)
    Df[1,1] <- 4*x[1]
    Df[1,2] <- 2*x[2]
    Df[2,1] <- exp(x[1]-1)
    Df[2,2] <- 5*x[2]^2

    Df
}

xstart <- c(2,0.5)
fstart <- dslnex(xstart)
xstart
fstart

# a solution is c(1,1)

nleqslv(xstart, dslnex, control=list(btol=.01))

# Cauchy start
nleqslv(xstart, dslnex, control=list(trace=1,btol=.01))

# Newton start
nleqslv(xstart, dslnex, control=list(trace=1,btol=.01,delta=-2.0))

# example for error message in case of an error in analytical jacobian

nleqslv(xstart, dslnex, BADjacdsln, method="Newton", 
                    control=list(btol=.01,chkjac=TRUE))

# singular function with a singular start

sngsrt <- function(x) {
    y <- numeric(length(x))
    y[1] <- x[1]^2/2 + x[2]
    y[2] <- x[1] + x[2]^2/2

    y
}

sngsrtjac <- function(x)  {
    n <- length(x)
    Df <- matrix(numeric(n*n),n,n)
    Df[1,1] <- x[1]
    Df[1,2] <- 1
    Df[2,1] <- 1
    Df[2,2] <- x[2]

    Df
}
xstart <- c(1,1)
nleqslv(xstart, sngsrt, sngsrtjac, global="dbldog",
        control=list(trace=1,btol=.01))



